Parser.finish()

Finalize parsing and return the root Node of the AST.

Usage

Parser.finish()

After calling this method, no more text can be fed to the parser. The returned Node can be used for tree inspection or rendering.

Returns

Node
The root document node of the parsed AST.

Raises

ValueError
If the parser is closed.