Parser.feed()
Feed a chunk of Markdown text to the parser.
Usage
Parser.feed(text)May be called multiple times before finishing. The concatenation of all fed chunks forms the complete document.
Parameters
text: str- Markdown content to append to the parse buffer.
Raises
ValueError-
If the parser has already been finished or closed.
TypeError- If text is not a string.